class KctTrail < ActiveRecord::Base

  has_many :kct_signs, -> { order(:km) }, :class_name => KctKilometraz
  has_many :kct_guideposts, :through => :kct_signs
  has_one :trail, :foreign_key => :kctref, :primary_key => :kctref
  include TrailCommons
  
  def exists_by_kctref?
    Trail.find_by_kctref(self.kctref) rescue false
  end
  def exist?; !trail.nil? end
  def exists?; exist? end
  
  def importable?
   !exists_by_kctref? and !osm_trail.nil?
  end

  def osm_trail
    result = OsmTrail.find_by_kctref(self.kctref)
    result = trail.osm_trail if result.nil? and !trail.nil?
    result
  end
  
  def trail_relative_distance(sign1,sign2); sign2.km - sign1.km end
  def trail_distance(sign1,sign2); trail_relative_distance(sign1,sign2).abs end
  def to_s; "kčt:#{kctref}" end
  def popis; "#{barva} #{typ} z #{kct_guideposts.first} do #{kct_guideposts.last}" end
  def barva_genetiv; Map.genetive_of_barva(barva) end
  
  def imported_guideposts_count
    kct_guideposts.select{|kg| kg.exists?}.size
  end
  
  def osm_trail_candidates_max_coinciding_guideposts
    osm_trail_candidates_hash.values.collect{|array| array.size}.max
  end
  
  def osm_trail_candidates_hash
    osm_trail_hash = Hash.new
    self.kct_guideposts.select{|kg| !kg.guidepost.nil?}.each do |kct_guidepost| 
      unless kct_guidepost.osm_guidepost.nil?
        osm_trails = kct_guidepost.osm_guidepost.osm_trails.where(:barva=>self.barva)
        osm_trails.each do |osm_trail|
          osm_trail_hash[osm_trail] = [] if osm_trail_hash[osm_trail].nil?
          osm_trail_hash[osm_trail] << kct_guidepost
        end
      end
    end
    osm_trail_hash
  end
  
  def delka # v kilometrech
    kct_signs.last.andand.km || 0
  end
  
  def self.symbol; '↩'.html_safe end # ↜

  # odhadne do jake zony tril patří
  def guess_zone
    kct_guideposts.first.kctref[0..1] || 'XX'   # TODO: nějak zjemnit, teď bere jen první rozc.
  end
end











